==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1beta1ClusterRoleFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1beta1ClusterRoleFluent<A extends V1beta1ClusterRoleFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildAggregationRule instead.
 * @return The buildable object.
 */
@Deprecated public V1beta1AggregationRule getAggregationRule();
    public V1beta1AggregationRule buildAggregationRule();
    public A withAggregationRule(V1beta1AggregationRule aggregationRule);
    public Boolean hasAggregationRule();
    public V1beta1ClusterRoleFluent.AggregationRuleNested<A> withNewAggregationRule();
    public V1beta1ClusterRoleFluent.AggregationRuleNested<A> withNewAggregationRuleLike(V1beta1AggregationRule item);
    public V1beta1ClusterRoleFluent.AggregationRuleNested<A> editAggregationRule();
    public V1beta1ClusterRoleFluent.AggregationRuleNested<A> editOrNewAggregationRule();
    public V1beta1ClusterRoleFluent.AggregationRuleNested<A> editOrNewAggregationRuleLike(V1beta1AggregationRule item);
    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ObjectMeta getMetadata();
    public V1ObjectMeta buildMetadata();
    public A withMetadata(V1ObjectMeta metadata);
    public Boolean hasMetadata();
    public V1beta1ClusterRoleFluent.MetadataNested<A> withNewMetadata();
    public V1beta1ClusterRoleFluent.MetadataNested<A> withNewMetadataLike(V1ObjectMeta item);
    public V1beta1ClusterRoleFluent.MetadataNested<A> editMetadata();
    public V1beta1ClusterRoleFluent.MetadataNested<A> editOrNewMetadata();
    public V1beta1ClusterRoleFluent.MetadataNested<A> editOrNewMetadataLike(V1ObjectMeta item);
    public A addToRules(int index,V1beta1PolicyRule item);
    public A setToRules(int index,V1beta1PolicyRule item);
    public A addToRules(V1beta1PolicyRule... items);
    public A addAllToRules(Collection<V1beta1PolicyRule> items);
    public A removeFromRules(V1beta1PolicyRule... items);
    public A removeAllFromRules(Collection<V1beta1PolicyRule> items);
    
/**
 * This method has been deprecated, please use method buildRules instead.
 * @return The buildable object.
 */
@Deprecated public List<V1beta1PolicyRule> getRules();
    public List<V1beta1PolicyRule> buildRules();
    public V1beta1PolicyRule buildRule(int index);
    public V1beta1PolicyRule buildFirstRule();
    public V1beta1PolicyRule buildLastRule();
    public V1beta1PolicyRule buildMatchingRule(io.kubernetes.client.fluent.Predicate<V1beta1PolicyRuleBuilder> predicate);
    public A withRules(List<V1beta1PolicyRule> rules);
    public A withRules(V1beta1PolicyRule... rules);
    public Boolean hasRules();
    public V1beta1ClusterRoleFluent.RulesNested<A> addNewRule();
    public V1beta1ClusterRoleFluent.RulesNested<A> addNewRuleLike(V1beta1PolicyRule item);
    public V1beta1ClusterRoleFluent.RulesNested<A> setNewRuleLike(int index,V1beta1PolicyRule item);
    public V1beta1ClusterRoleFluent.RulesNested<A> editRule(int index);
    public V1beta1ClusterRoleFluent.RulesNested<A> editFirstRule();
    public V1beta1ClusterRoleFluent.RulesNested<A> editLastRule();
    public V1beta1ClusterRoleFluent.RulesNested<A> editMatchingRule(io.kubernetes.client.fluent.Predicate<V1beta1PolicyRuleBuilder> predicate);

    public interface AggregationRuleNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1AggregationRuleFluent<V1beta1ClusterRoleFluent.AggregationRuleNested<N>>{

        
    public N and();    public N endAggregationRule();
}
    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ObjectMetaFluent<V1beta1ClusterRoleFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface RulesNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1PolicyRuleFluent<V1beta1ClusterRoleFluent.RulesNested<N>>{

        
    public N and();    public N endRule();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1beta1ClusterRoleFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.kubernetes.client.fluent.Fluent;
import java.lang.StringBuffer;
import java.util.Collection;

public interface V1beta1ClusterRoleFluent<A extends V1beta1ClusterRoleFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildAggregationRule instead.
 * @return The buildable object.
 */
@Deprecated public V1beta1AggregationRule getAggregationRule();
    public V1beta1AggregationRule buildAggregationRule();
    public A withAggregationRule(V1beta1AggregationRule aggregationRule);
    public Boolean hasAggregationRule();
    public V1beta1ClusterRoleFluent.AggregationRuleNested<A> withNewAggregationRule();
    public V1beta1ClusterRoleFluent.AggregationRuleNested<A> withNewAggregationRuleLike(V1beta1AggregationRule item);
    public V1beta1ClusterRoleFluent.AggregationRuleNested<A> editAggregationRule();
    public V1beta1ClusterRoleFluent.AggregationRuleNested<A> editOrNewAggregationRule();
    public V1beta1ClusterRoleFluent.AggregationRuleNested<A> editOrNewAggregationRuleLike(V1beta1AggregationRule item);
    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ObjectMeta getMetadata();
    public V1ObjectMeta buildMetadata();
    public A withMetadata(V1ObjectMeta metadata);
    public Boolean hasMetadata();
    public V1beta1ClusterRoleFluent.MetadataNested<A> withNewMetadata();
    public V1beta1ClusterRoleFluent.MetadataNested<A> withNewMetadataLike(V1ObjectMeta item);
    public V1beta1ClusterRoleFluent.MetadataNested<A> editMetadata();
    public V1beta1ClusterRoleFluent.MetadataNested<A> editOrNewMetadata();
    public V1beta1ClusterRoleFluent.MetadataNested<A> editOrNewMetadataLike(V1ObjectMeta item);
    public A addToRules(int index,V1beta1PolicyRule item);
    public A setToRules(int index,V1beta1PolicyRule item);
    public A addToRules(V1beta1PolicyRule... items);
    public A addAllToRules(Collection<V1beta1PolicyRule> items);
    public A removeFromRules(V1beta1PolicyRule... items);
    public A removeAllFromRules(Collection<V1beta1PolicyRule> items);
    
/**
 * This method has been deprecated, please use method buildRules instead.
 * @return The buildable object.
 */
@Deprecated public List<V1beta1PolicyRule> getRules();
    public List<V1beta1PolicyRule> buildRules();
    public V1beta1PolicyRule buildRule(int index);
    public V1beta1PolicyRule buildFirstRule();
    public V1beta1PolicyRule buildLastRule();
    public V1beta1PolicyRule buildMatchingRule(io.kubernetes.client.fluent.Predicate<V1beta1PolicyRuleBuilder> predicate);
    public Boolean hasMatchingRule(io.kubernetes.client.fluent.Predicate<V1beta1PolicyRuleBuilder> predicate);
    public A withRules(List<V1beta1PolicyRule> rules);
    public A withRules(V1beta1PolicyRule... rules);
    public Boolean hasRules();
    public V1beta1ClusterRoleFluent.RulesNested<A> addNewRule();
    public V1beta1ClusterRoleFluent.RulesNested<A> addNewRuleLike(V1beta1PolicyRule item);
    public V1beta1ClusterRoleFluent.RulesNested<A> setNewRuleLike(int index,V1beta1PolicyRule item);
    public V1beta1ClusterRoleFluent.RulesNested<A> editRule(int index);
    public V1beta1ClusterRoleFluent.RulesNested<A> editFirstRule();
    public V1beta1ClusterRoleFluent.RulesNested<A> editLastRule();
    public V1beta1ClusterRoleFluent.RulesNested<A> editMatchingRule(io.kubernetes.client.fluent.Predicate<V1beta1PolicyRuleBuilder> predicate);

    public interface AggregationRuleNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1AggregationRuleFluent<V1beta1ClusterRoleFluent.AggregationRuleNested<N>>{

        
    public N and();    public N endAggregationRule();
}
    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ObjectMetaFluent<V1beta1ClusterRoleFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface RulesNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1PolicyRuleFluent<V1beta1ClusterRoleFluent.RulesNested<N>>{

        
    public N and();    public N endRule();
}


}
